@@ -1,9 +1,9 @@
-#!/usr/bin/python2.7
+#!/usr/bin/python3
 
 #
-# Copyright 2011-2017 Univention GmbH
+# Copyright 2011-2021 Univention GmbH
 #
-# http://www.univention.de/
+# https://www.univention.de/
 #
 # All rights reserved.
 #
@@ -26,7 +26,7 @@
 # You should have received a copy of the GNU Affero General Public
 # License with the Debian GNU/Linux or Univention distribution in file
 # /usr/share/common-licenses/AGPL-3; if not, see
-# <http://www.gnu.org/licenses/>.
+# <https://www.gnu.org/licenses/>.
 
 # This script was adjusted from the Tests for ntacls manipulation
 # Copyright (C) Matthieu Patou <mat@matws.net> 2009-2010
@@ -42,11 +42,13 @@
 # GNU General Public License for more details.
 #
 # You should have received a copy of the GNU General Public License
-# along with this program.  If not, see <http://www.gnu.org/licenses/>.
+# along with this program.  If not, see <https://www.gnu.org/licenses/>.
 #
 
 """Set user_xattr option on ext2/ext3/ext4 filesystems, remount if necessary"""
 
+from __future__ import print_function
+
 from univention.lib import fstab
 import subprocess
 
@@ -79,7 +81,7 @@ def _modify_extfs_option(options=[], activate=True, devices=[]):
 			if fstab_partition and fstab_partition.type in ('ext3', 'ext4'):
 				target_partitions.append(fstab_partition)
 			else:
-				print 'Device could not be found: %s' % device
+				print('Device could not be found: %s' % device)
 	else:
 		for fstype in ('ext2', 'ext3', 'ext4'):
 			for fstab_partition in fs.get(fstype, ignore_root=False):
@@ -89,7 +91,7 @@ def _modify_extfs_option(options=[], activate=True, devices=[]):
 		if _do_modify_extfs_option(fstab_partition, options, activate):
 			fs.save()
 			if subprocess.call(('mount', '-o', 'remount', fstab_partition.spec)):
-				print 'Remounting partition failed: %s' % fstab_partition.spec
+				print('Remounting partition failed: %s' % fstab_partition.spec)
 
 
 if __name__ == '__main__':
